Package: rredlist
Type: Package
Title: 'IUCN' Red List Client
Description: 'IUCN' Red List (<https://api.iucnredlist.org/>) client.
    The 'IUCN' Red List is a global list of threatened and endangered species.
    Functions cover all of the Red List 'API' routes. An 'API' key is required.
Version: 1.1.1
Authors@R: 
    c(person(given = "William",
             family = "Gearty",
             role = c("aut", "cre"),
             email = "willgearty@gmail.com",
             comment = c(ORCID = "0000-0003-0076-3262")),
      person(given = "Scott",
             family = "Chamberlain",
             role = c("aut"),
             email = "myrmecocystus@gmail.com",
             comment = c(ORCID = "0000-0003-1444-9135")),
      person(given = "rOpenSci",
             role = "fnd",
             comment = c(ROR = "019jywm96")),
      person(given = "Maëlle",
             family = "Salmon",
             role = "ctb",
             email = "maelle.salmon@yahoo.se",
             comment = c(ORCID = "0000-0002-2815-0399")),
      person(given = "Kevin",
             family = "Cazelles",
             role = "rev",
             email = "kevin.cazelles@insileco.io", 
             comment = c(ORCID = "0000-0001-6619-9874")),
      person(given = "Stephanie",
             family = "Hazlitt",
             role = "rev",
             email = "stephhazlitt@gmail.com",
             comment = c(ORCID = "0000-0002-3161-2304"))
      )
License: MIT + file LICENSE
URL: https://docs.ropensci.org/rredlist/,
        https://github.com/ropensci/rredlist
BugReports: https://github.com/ropensci/rredlist/issues
Encoding: UTF-8
Language: en-US
Imports: crul (>= 0.3.8), jsonlite (>= 1.1), lifecycle, cli, curl,
        rlang
Suggests: spelling, testthat, vcr (>= 0.6.0), knitr, rmarkdown,
        webmockr, microbenchmark, ggplot2, dplyr, tibble, tidyr,
        patchwork, vdiffr
RoxygenNote: 7.3.2.9000
VignetteBuilder: knitr
X-schema.org-applicationCategory: Biodiversity
X-schema.org-keywords: IUCN, biodiversity, API, web-services, traits,
        habitat, species, conservation
X-schema.org-isPartOf: https://ropensci.org
NeedsCompilation: no
Packaged: 2025-09-03 19:20:32 UTC; willg
Author: William Gearty [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0076-3262>),
  Scott Chamberlain [aut] (ORCID:
    <https://orcid.org/0000-0003-1444-9135>),
  rOpenSci [fnd] (ROR: <https://ror.org/019jywm96>),
  Maëlle Salmon [ctb] (ORCID: <https://orcid.org/0000-0002-2815-0399>),
  Kevin Cazelles [rev] (ORCID: <https://orcid.org/0000-0001-6619-9874>),
  Stephanie Hazlitt [rev] (ORCID:
    <https://orcid.org/0000-0002-3161-2304>)
Maintainer: William Gearty <willgearty@gmail.com>
Repository: CRAN
Date/Publication: 2025-09-04 07:20:02 UTC
