# nocov start

release_questions <- function() {
  c(
    "Did you update the CITATION file?",
    "Did you update and knit the README?",
    "Did you rebuild the codemeta.json file using codemetar?",
    "Did you rebuild the vignette(s) using `vignettes/precompile.R`?"
  )
}

# nocov end
