list(
  rd_family_title = list(taxa = "Assessments by taxa:",
                         stats = "Red List information and statistics:",
                         habitat = "Assessments by habitats and systems:",
                         geo = "Assessments by geographic regions:",
                         conservation = "Assessments by conservation actions or research needed:",
                         threats = "Assessments by threat details:",
                         groups = "Assessments for specific sets of taxa")
)
